@@ -11,6 +11,11 @@ pub const THRESHOLD: i32 = 10;
 pub type Tuple0_0 = ();
 pub type Int8 = i8;
 
+#[macro_export]
+macro_rules! micro {
+        () => {};
+}
+
 pub struct Unit;
 
 pub fn array_length(array: &[u8]) -> usize {
